@@ -30,6 +30,7 @@ BASE_HEADERS = {
     "Content-Type": "application/json",
 }
 
+
 class Rivian:
     """Main class for the Rivian API Client"""
 
@@ -45,6 +46,8 @@ class Rivian:
         self._session_token = ""
         self._access_token = ""
         self._refresh_token = ""
+        self._app_session_token = ""
+        self._user_session_token = ""
 
         self.client_id = client_id
         self.client_secret = client_secret
@@ -127,9 +130,11 @@ class Rivian:
 
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "Authorization": "Bearer " + self._session_token,
-        })
+        headers.update(
+            {
+                "Authorization": "Bearer " + self._session_token,
+            }
+        )
 
         json_data = {
             "grant_type": "password",
@@ -237,7 +242,6 @@ class Rivian:
 
         return response
 
-
     async def get_vehicle_info(
         self, vin: str, access_token: str, properties: dict[str]
     ) -> dict[str, Any]:
@@ -246,9 +250,11 @@ class Rivian:
 
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "Authorization": "Bearer " + self._access_token,
-        })
+        headers.update(
+            {
+                "Authorization": "Bearer " + access_token,
+            }
+        )
 
         json_data = {
             "car": vin,
@@ -298,11 +304,9 @@ class Rivian:
 
         return response
 
-    async def create_csrf_token(
-        self
-    ) -> dict[str, Any]:
+    async def create_csrf_token(self) -> dict[str, Any]:
         """create cross-site-request-forgery (csrf) token"""
-        
+
         url = GRAPHQL_GATEWAY
 
         headers = dict()
@@ -311,11 +315,11 @@ class Rivian:
         graphql_json = {
             "operationName": "CreateCSRFToken",
             "query": "mutation CreateCSRFToken {\n  createCsrfToken {\n    __typename\n    csrfToken\n    appSessionToken\n  }\n}",
-            "variables": None
+            "variables": None,
         }
 
         response = await self.__graphql_query(headers, url, graphql_json)
-        
+
         response_json = await response.json()
 
         csrf_data = response_json["data"]["createCsrfToken"]
@@ -324,162 +328,155 @@ class Rivian:
 
         return response
 
-    
     async def authenticate_graphql(
-        self, 
+        self,
         username: str,
         password: str,
     ) -> dict[str, Any]:
         """Authenticate against the Rivian GraphQL API with Username and Password"""
-        
+
         url = GRAPHQL_GATEWAY
 
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "Csrf-Token": self._csrf_token,
-            "A-Sess": self._app_session_token,
-            "Apollographql-Client-Name": "com.rivian.ios.consumer-apollo-ios"
-        })
+        headers.update(
+            {
+                "Csrf-Token": self._csrf_token,
+                "A-Sess": self._app_session_token,
+                "Apollographql-Client-Name": "com.rivian.ios.consumer-apollo-ios",
+            }
+        )
 
         graphql_json = {
             "operationName": "Login",
             "query": "mutation Login($email: String!, $password: String!) {\n  login(email: $email, password: $password) {\n    __typename\n    ... on MobileLoginResponse {\n      __typename\n      accessToken\n      refreshToken\n      userSessionToken\n    }\n    ... on MobileMFALoginResponse {\n      __typename\n      otpToken\n    }\n  }\n}",
-            "variables": {
-                "email": username,
-                "password": password
-            }
+            "variables": {"email": username, "password": password},
         }
 
         response = await self.__graphql_query(headers, url, graphql_json)
-        
+
         response_json = await response.json()
         self._access_token = response_json["data"]["login"]["accessToken"]
         self._refresh_token = response_json["data"]["login"]["refreshToken"]
         self._user_session_token = response_json["data"]["login"]["userSessionToken"]
-        
+
         return response
 
-
-    async def get_user_information(
-        self
-    ) -> ClientResponse:
+    async def get_user_information(self) -> ClientResponse:
         """get user information (user.id, vehicle vins)"""
         url = GRAPHQL_GATEWAY
-        
+
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "A-Sess": self._app_session_token,
-            "U-Sess": self._user_session_token
-        })
-        
+        headers.update(
+            {"A-Sess": self._app_session_token, "U-Sess": self._user_session_token}
+        )
+
         graphql_json = {
             "operationName": "getUserInfo",
             "query": "query getUserInfo {\n    currentUser {\n        __typename\n        id\n        vehicles {\n        id\n        vin\n        vas {\n            __typename\n            vasVehicleId\n            vehiclePublicKey\n        }\n        roles\n        state\n        createdAt\n        updatedAt\n        vehicle {\n            __typename\n            id\n            vin\n            modelYear\n            make\n            model\n            expectedBuildDate\n            plannedBuildDate\n            expectedGeneralAssemblyStartDate\n            actualGeneralAssemblyDate\n        }\n        }\n    }\n}",
-            "variables": None
+            "variables": None,
         }
 
         return await self.__graphql_query(headers, url, graphql_json)
 
-
-    async def get_registered_wallboxes(
-        self
-    ) -> ClientResponse:
+    async def get_registered_wallboxes(self) -> ClientResponse:
         """get wallboxes (graphql)"""
         url = GRAPHQL_CHARGING
-        
+
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "Csrf-Token": self._csrf_token,
-            "A-Sess": self._app_session_token,
-            "U-Sess": self._user_session_token
-        })
-        
+        headers.update(
+            {
+                "Csrf-Token": self._csrf_token,
+                "A-Sess": self._app_session_token,
+                "U-Sess": self._user_session_token,
+            }
+        )
+
         graphql_json = {
             "operationName": "getRegisteredWallboxes",
             "query": "query getRegisteredWallboxes {\n  getRegisteredWallboxes {\n    __typename\n    wallboxId\n    userId\n    wifiId\n    name\n    linked\n    latitude\n    longitude\n    chargingStatus\n    power\n    currentVoltage\n    currentAmps\n    softwareVersion\n    model\n    serialNumber\n    maxAmps\n    maxVoltage\n    maxPower\n  }\n}",
-            "variables": None
+            "variables": None,
         }
 
         return await self.__graphql_query(headers, url, graphql_json)
-    
 
     async def get_vehicle_state(
         self, vin: str, properties: dict[str]
     ) -> ClientResponse:
         """get vehicle state (graphql)"""
         url = GRAPHQL_GATEWAY
-        
+
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "A-Sess": self._app_session_token,
-            "U-Sess": self._user_session_token
-        })
+        headers.update(
+            {"A-Sess": self._app_session_token, "U-Sess": self._user_session_token}
+        )
 
-        graphql_query = "query GetVehicleState($vehicleID: String!) {\n  vehicleState(id: $vehicleID) {\n    __typename\n:   "
-        gnss_attribute_template = "{\n      __typename\n      latitude\n      longitude\n      timeStamp\n    }\n"
-        generic_sensor_template = "{\n      __typename\n      timeStamp\n      value\n    }\n"
+        graphql_query = "query GetVehicleState($vehicleID: String!) {\n  vehicleState(id: $vehicleID) {\n    "
+        gnss_attribute_template = (
+            "{\n      latitude\n      longitude\n      timeStamp\n    }\n"
+        )
+        generic_sensor_template = "{\n      timeStamp\n      value\n    }\n"
 
         for key in properties:
             template = generic_sensor_template
-            if key == 'gnssLocation':
+            if key == "gnssLocation":
                 template = gnss_attribute_template
-        
-            graphql_query += f'{key} {template}'
-        graphql_query += '}'
-        
+
+            graphql_query += f"{key} {template}"
+        graphql_query += "}"
+        graphql_query += "}"
+
         graphql_json = {
-            "operationName":"GetVehicleState",
-            "query":graphql_query,
-            "variables": { 
-                "vehicleID": vin
-            }
+            "operationName": "GetVehicleState",
+            "query": graphql_query,
+            "variables": {"vehicleID": vin},
         }
 
         return await self.__graphql_query(headers, url, graphql_json)
 
-
     async def get_live_charging_session(
         self, user_id: str, vin: str, properties: dict[str]
     ) -> ClientResponse:
         """get live charging session data (graphql)"""
         url = GRAPHQL_CHARGING
-        
+
         headers = dict()
         headers.update(BASE_HEADERS)
-        headers.update({
-            "U-Sess": self._user_session_token
-        })
+        headers.update({"U-Sess": self._user_session_token})
 
-        graphql_query = "query getLiveSessionData($vehicleId: ID!) {\n  getLiveSessionData(vehicleId: $vehicleId) {\n    __typename\n:   "
-        detail_sensors = ['vehicleChargerState', 'timeRemaining', 'kilometersChargedPerHour', 'power', 'rangeAddedThisSession', 'totalChargedEnergy']
-        detail_sensor_template = "{\n      __typename\n      value\n      updatedAt\n    }\n"
+        graphql_query = "query getLiveSessionData($vehicleId: ID!) {\n  getLiveSessionData(vehicleId: $vehicleId) {\n    __typename\n   "
+        detail_sensors = [
+            "vehicleChargerState",
+            "timeRemaining",
+            "kilometersChargedPerHour",
+            "power",
+            "rangeAddedThisSession",
+            "totalChargedEnergy",
+        ]
+        detail_sensor_template = (
+            "{\n      __typename\n      value\n      updatedAt\n    }\n"
+        )
 
         for key in properties:
-            template = ''
+            template = ""
             if key in detail_sensors:
                 template = detail_sensor_template
-            graphql_query += f'{key} {template}'
-        graphql_query += '}'
-        
+            graphql_query += f"{key} {template}"
+        graphql_query += "}"
+        graphql_query += "}"
+
         graphql_json = {
-            "operationName":"getLiveSessionData",
-            "query":graphql_query,
-            "variables": { 
-                "userId": user_id,
-                "vehicleId": vin
-            }
+            "operationName": "getLiveSessionData",
+            "query": graphql_query,
+            "variables": {"userId": user_id, "vehicleId": vin},
         }
 
         return await self.__graphql_query(headers, url, graphql_json)
 
-
-    async def __graphql_query(
-        self, headers: dict(str, str), url: str, body: str
-    ):
+    async def __graphql_query(self, headers: dict(str, str), url: str, body: str):
         """execute and return arbitrary graphql query"""
         if self._session is None:
             self._session = aiohttp.ClientSession()
@@ -503,14 +500,17 @@ class Rivian:
             ) from exception
 
         if response.status != 200:
-            raise Exception("Error occurred while reading the graphql response from Rivian.")
-            
-        response_json = await response.json()
-        if 'errors' in response_json:
-            raise Exception("Error occurred while reading the graphql response from Rivian.")
-        
-        return response
+            raise Exception(
+                "Error occurred while reading the graphql response from Rivian."
+            )
 
+        response_json = await response.json()
+        if "errors" in response_json:
+            raise Exception(
+                "Error occurred while reading the graphql response from Rivian."
+            )
+
+        return response
 
     async def close(self) -> None:
         """Close open client session."""
